@@ -20,7 +20,7 @@
  * USA
  *
  * --------------------------------------------------------------------------
- * $Id: JonasServerAction.java 7419 2011-01-11 11:37:29Z alitokmen $
+ * $Id: JonasServerAction.java 10053 2012-05-29 13:35:49Z pelletib $
  * --------------------------------------------------------------------------
  */
 package org.ow2.jasmine.jadort.service.action;
@@ -194,10 +194,14 @@ public class JonasServerAction extends ServerAction {
         this.checkJMXConnection();
 
         if (ApplicationType.OSGI.equals(applicationType)) {
-            if (this.serverVersion.startsWith("5.2.0-M3")) {
-                throw new JadortServiceException("The server '" + this.name + "' is running OW2 JOnAS version 5.2.0-M3. "
-                    + "Due to the bug http://jira.ow2.org/browse/JONAS-292 OSGi migration is not possible on that version. "
-                    + "Please upgrade your target JOnAS server's version using the \"Maintenance\" functions instead.", null);
+            if ((this.serverVersion.compareTo("5.1.3") >= 0 && this.serverVersion.compareTo("5.1.6") <= 0)
+                || this.serverVersion.startsWith("5.2.0-M3")) {
+
+                throw new JadortServiceException("The server '" + this.name
+                    + "' is running OW2 JOnAS version between 5.1.3 and "
+                    + "5.1.6 or version 5.2.0-M3. Due to the bug http://jira.ow2.org/browse/JONAS-292 OSGi migration is not "
+                    + "possible on any of these versions. Please upgrade your target JOnAS server's version using the "
+                    + "\"Maintenance\" functions instead.", null);
             }
         }
 
@@ -231,7 +235,7 @@ public class JonasServerAction extends ServerAction {
         List<String> deployedJars = (List<String>) this.mbscnx.getAttribute(this.j2eeServer, "deployedJars");
 
         // All EARs, will later only contain non-versioned EARs
-        Set<ObjectName> ears = (Set<ObjectName>) this.mbscnx.queryNames(new ObjectName("*:j2eeType=J2EEApplication,*"), null);
+        Set<ObjectName> ears = this.mbscnx.queryNames(new ObjectName("*:j2eeType=J2EEApplication,*"), null);
 
         // Key = real ObjectName, Value = manager ObjectName. This therefore
         // implies that there'll be multiple keys pointing to the same value if
@@ -298,8 +302,8 @@ public class JonasServerAction extends ServerAction {
 
         // Process all versioned items
         for (Map.Entry<ObjectName, ObjectName> versionedEjbOrWar : versionedEjbsAndWars.entrySet()) {
-            for (Map.Entry<String, String> context : ((Map<String, String>) this.mbscnx.getAttribute(versionedEjbOrWar
-                .getValue(), "Contexts")).entrySet()) {
+            for (Map.Entry<String, String> context : ((Map<String, String>) this.mbscnx.getAttribute(
+                versionedEjbOrWar.getValue(), "Contexts")).entrySet()) {
                 ObjectName j2eeApplication;
                 String applicationName = versionedEjbOrWar.getKey().getKeyProperty("J2EEApplication");
                 if (applicationName == null || applicationName.equals("none") || applicationName.equals("null")) {
@@ -541,8 +545,7 @@ public class JonasServerAction extends ServerAction {
         this.checkJMXConnection();
 
         // If the depmonitor service is here, make sure it is not in development
-        Set<ObjectName> depmonitor = (Set<ObjectName>) this.mbscnx.queryNames(new ObjectName("*:type=service,name=depmonitor"),
-            null);
+        Set<ObjectName> depmonitor = this.mbscnx.queryNames(new ObjectName("*:type=service,name=depmonitor"), null);
         if (!depmonitor.isEmpty()) {
             ObjectName depmonitorService = depmonitor.iterator().next();
             boolean developmentMode;
@@ -697,8 +700,8 @@ public class JonasServerAction extends ServerAction {
         String versionID_EJB = version + "/";
         for (ObjectName manager : managers) {
             for (String context : ((Map<String, String>) this.mbscnx.getAttribute(manager, "Contexts")).keySet()) {
-                if (context.contains(versionID_WAR) || context.contains(versionID_EJB)
-                    || context.contains(versionID_WAR_old) || context.contains(versionID_EJB_old)) {
+                if (context.contains(versionID_WAR) || context.contains(versionID_EJB) || context.contains(versionID_WAR_old)
+                    || context.contains(versionID_EJB_old)) {
 
                     Object[] opParams = new Object[] {context, policy};
                     String[] opSignature = new String[] {"java.lang.String", "java.lang.String"};
@@ -957,7 +960,7 @@ public class JonasServerAction extends ServerAction {
             try {
                 Object[] opParams = new Object[] {this.name, null, null};
                 String[] opSignature = new String[] {String.class.getName(), String.class.getName(), String.class.getName()};
-                managerMbscnx.invoke(cdObjectName, "start", opParams, opSignature);
+                managerMbscnx.invoke(cdObjectName, "startJOnAS", opParams, opSignature);
             } finally {
                 managerConnector.close();
                 managerConnector = null;
